@@ -51,6 +51,10 @@ from enhancedlabelme.widgets import ZoomWidget
 LABEL_COLORMAP = imgviz.label_colormap(value=200)
 os.environ['QT_API'] = 'pyqt5'
 
+class th:
+    def __init__(self):
+        self.a=3
+
 class MainWindow(QtWidgets.QMainWindow):
 
     FIT_WINDOW, FIT_WIDTH, MANUAL_ZOOM = 0, 1, 2
@@ -70,7 +74,7 @@ class MainWindow(QtWidgets.QMainWindow):
             )
             if output_file is None:
                 output_file = output
-
+        
         # see labelme/config/default_config.yaml for valid configuration
         if config is None:
             config = get_config()
@@ -164,6 +168,7 @@ class MainWindow(QtWidgets.QMainWindow):
         self.canvas = self.labelList.canvas = Canvas(
             epsilon=self._config['epsilon'],
             double_click=self._config['canvas']['double_click'],
+            cross_hair=self._config['cross_hair'],
         )
         self.canvas.zoomRequest.connect(self.zoomRequest)
 
@@ -375,7 +380,10 @@ class MainWindow(QtWidgets.QMainWindow):
                          enabled=False)
 
         help = action(self.tr('&About'), self.about, icon='help',
-                      tip=self.tr('About LabelMe-Modified'))
+                      tip=self.tr('About EnhancedLabelMe'))
+        
+        readme = action(self.tr('&Readme'), self.readme, icon='icon',
+                      tip=self.tr('Open README.md'))
         
         prefer = action(self.tr('&Preference'), self.preference, icon='edit',
                       tip=self.tr('Configure preference'))
@@ -425,6 +433,9 @@ class MainWindow(QtWidgets.QMainWindow):
             "Adjust brightness and contrast",
             enabled=False,
         )
+        crossHair = action(self.tr('&Toggle cross hair(+)'), self.crossHairToggle,
+                tip=self.tr('Show cross hair around the mouse cursor'), checkable=True, checked=self._config['cross_hair'],)
+        crossHair.setChecked(self._config['cross_hair'])
         darkMode = action(self.tr('&Toggle dark theme'), self.darkModeToggle,
                 tip=self.tr('Toggle dark theme'), checkable=True, checked=self._config['dark_mode'],)
 
@@ -493,6 +504,7 @@ class MainWindow(QtWidgets.QMainWindow):
             openNextImg=openNextImg, openPrevImg=openPrevImg,
             fileMenuActions=(open_, opendir, save, saveAs, close, quit),
             tool=(),
+            crossHair=crossHair,
             darkMode=darkMode,
             # XXX: need to add some actions here to activate the shortcut
             editMenu=(
@@ -570,7 +582,7 @@ class MainWindow(QtWidgets.QMainWindow):
                 quit,
             ),
         )
-        utils.addActions(self.menus.help, (help,))
+        utils.addActions(self.menus.help, (help, readme))
         utils.addActions(
             self.menus.view,
             (
@@ -579,6 +591,8 @@ class MainWindow(QtWidgets.QMainWindow):
                 self.shape_dock.toggleViewAction(),
                 self.file_dock.toggleViewAction(),
                 None,
+                crossHair,
+                None,
                 fill_drawing,
                 None,
                 hideAll,
@@ -825,22 +839,21 @@ class MainWindow(QtWidgets.QMainWindow):
             subprocess.call(('open', os.path.join(os.path.expanduser('~'), 'labelme+config')))
         elif platform.system() == 'Windows':    # Windows
             subprocess.call(('notepad.exe', os.path.join(os.path.expanduser('~'), 'labelme+config')))
-            #tempwindow = 'notepad.exe ' + os.path.join(os.path.expanduser('~'), 'labelme+config')
-            #os.startfile(tempwindow)
         else:                                   # linux variants
             subprocess.call(('xdg-open', os.path.join(os.path.expanduser('~'), 'labelme+config')))
 
     def about(self):
-        f01 = "\n- Added some keys to json data (['loadTime'], ['saveTime']"
-        f02 = '\n- Removed double click function when creating polygon'
-        f03 = '\n- Always dump json in utf-8 encoding'
-        f04 = '\n- Automatically check "Save Automatically"'
-        f05 = '\n- Added Progress indication in the Main window title : (# of images/# of jsons)'
-        f06 = '\n- Added the Preference in menubar (File - Preference)'
-        f07 = '\n- Launch program in fullscreen mode'
-        f08 = '\n- Added dark theme (Edit - Toggle dark theme)'
         return QtWidgets.QMessageBox.about(
-            self, 'About', '\n<Version %s>%s'%(__version__, f01 + f02 + f03 + f04 + f05 + f06 + f07 + f08))
+            self, 'About', '\n<Version %s>\n%s'%(__version__, "Modified by LilactheGreat"))
+        
+    def readme(self):
+        import platform, subprocess
+        if platform.system() == 'Darwin':       # macOS
+            subprocess.call(('open', 'README.md'))
+        elif platform.system() == 'Windows':    # Windows
+            subprocess.call(('notepad.exe', 'README.md'))
+        else:                                   # linux variants
+            subprocess.call(('xdg-open', 'README.md'))
         
     def darkModeToggle(self):
         app = QtWidgets.QApplication.instance()
@@ -850,7 +863,13 @@ class MainWindow(QtWidgets.QMainWindow):
             app.setStyleSheet(qdarkstyle.load_stylesheet())
         elif self.actions.darkMode.isChecked() == False:
             app.setStyleSheet("")
-
+            
+    def crossHairToggle(self):
+        if self.actions.crossHair.isChecked() == True:
+            self.canvas.cross = True
+        elif self.actions.crossHair.isChecked() == False:
+            self.canvas.cross = False
+    
     def toggleDrawingSensitive(self, drawing=True):
         """Toggle drawing sensitive.
 
@@ -1849,6 +1868,7 @@ class MainWindow(QtWidgets.QMainWindow):
         lst = []
         for i in range(self.fileListWidget.count()):
             item = self.fileListWidget.item(i)
+            # item_temp = str(osp.basename(item.text())) + str('(%s)'%(osp.dirname(item.text())))
             lst.append(item.text())
         return lst
 
