@@ -2,11 +2,12 @@ from qtpy import QtCore
 from qtpy import QtGui
 from qtpy import QtWidgets
 
+import sys  
+
 from enhancedlabelme import QT5
 from enhancedlabelme.shape import Shape
 import enhancedlabelme.utils
 
-
 # TODO(unknown):
 # - [maybe] Find optimal epsilon value.
 
@@ -39,6 +40,8 @@ class Canvas(QtWidgets.QWidget):
     def __init__(self, *args, **kwargs):
         self.epsilon = kwargs.pop('epsilon', 10.0)
         self.double_click = kwargs.pop('double_click', 'None')
+        self.cross_onoff = kwargs.pop('cross_hair')
+        print(self.cross_onoff)
         if self.double_click not in [None, 'close']:
             raise ValueError(
                 'Unexpected value for double_click event: {}'
@@ -81,6 +84,9 @@ class Canvas(QtWidgets.QWidget):
         # Set widget options.
         self.setMouseTracking(True)
         self.setFocusPolicy(QtCore.Qt.WheelFocus)
+        self.eventc = None
+        self.cross = False
+        self.posc = None
 
     def fillDrawing(self):
         return self._fill_drawing
@@ -168,12 +174,13 @@ class Canvas(QtWidgets.QWidget):
                 pos = self.transformPos(ev.localPos())
             else:
                 pos = self.transformPos(ev.posF())
+            self.posc = pos
         except AttributeError:
             return
-
+        
         self.prevMovePoint = pos
         self.restoreCursor()
-
+        
         # Polygon drawing.
         if self.drawing():
             self.line.shape_type = self.createMode
@@ -181,7 +188,7 @@ class Canvas(QtWidgets.QWidget):
             self.overrideCursor(CURSOR_DRAW)
             if not self.current:
                 return
-
+            
             if self.outOfPixmap(pos):
                 # Don't allow the user to draw outside the pixmap.
                 # Project the point to the pixmap's edges.
@@ -214,6 +221,12 @@ class Canvas(QtWidgets.QWidget):
             self.repaint()
             self.current.highlightClear()
             return
+        
+        if not self.drawing():
+            try:
+                del ex
+            except Exception:
+                pass
 
         # Polygon copy moving.
         if QtCore.Qt.RightButton & ev.buttons():
@@ -488,7 +501,7 @@ class Canvas(QtWidgets.QWidget):
             self.storeShapes()
             self.selectedShapes = []
             self.update()
-        return deleted_shapesz
+        return deleted_shapes
 
     def copySelectedShapes(self):
         if self.selectedShapes:
@@ -510,8 +523,8 @@ class Canvas(QtWidgets.QWidget):
     def paintEvent(self, event):
         if not self.pixmap:
             return super(Canvas, self).paintEvent(event)
-
-        p = self._painter
+        self.eventc = event
+        p = self._painter       
         p.begin(self)
         p.setRenderHint(QtGui.QPainter.Antialiasing)
         p.setRenderHint(QtGui.QPainter.HighQualityAntialiasing)
@@ -522,6 +535,13 @@ class Canvas(QtWidgets.QWidget):
         
         p.drawPixmap(0, 0, self.pixmap)
         Shape.scale = self.scale
+        
+        if self.cross == True:
+            p.setPen(QtGui.QPen(QtCore.Qt.blue, 1, QtCore.Qt.DashLine))
+            p.drawLine(self.posc.x(), self.pixmap.height(), self.posc.x(), 0)
+            p.drawLine(0, self.posc.y(), self.pixmap.width(), self.posc.y())
+            self.update()
+
         for shape in self.shapes:
             if (shape.selected or not self._hideBackround) and \
                     self.isVisible(shape):
@@ -556,7 +576,7 @@ class Canvas(QtWidgets.QWidget):
         x = (aw - w) / (2 * s) if aw > w else 0
         y = (ah - h) / (2 * s) if ah > h else 0
         return QtCore.QPoint(x, y)
-
+    
     def outOfPixmap(self, p):
         w, h = self.pixmap.width(), self.pixmap.height()
         return not (0 <= p.x() <= w - 1 and 0 <= p.y() <= h - 1)
